﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 영역 시리즈
        /// </summary>
        private Area area;

        /// <summary>
        /// 트렌드 함수
        /// </summary>
        private TrendFunction trendFunction;

        /// <summary>
        /// 라인 시리즈
        /// </summary>
        private Line line;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 영역 시리즈를 생성한다.

            this.area = new Area();

            this.area.Title           = "Data";
            this.area.Color           = Color.FromArgb(68, 102, 163);
            this.area.AreaBrush.Color = Color.FromArgb(68, 102, 163);
            this.area.AreaLines.Color = Color.FromArgb(41, 61 , 98 );

            #endregion
            #region 트렌드 함수를 생성한다.

            this.trendFunction = new TrendFunction();

            #endregion
            #region 라인 시리즈를 생성한다.

            this.line = new Line();

            this.line.Brush.Color = Color.FromArgb(243, 156, 53);
            this.line.Color       = Color.FromArgb(243, 156, 53);
            this.line.DataSource  = this.area;
            this.line.Function    = this.trendFunction;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Series.Add(this.area);
            this.tChart.Series.Add(this.line);

            #endregion

            this.area.FillSampleValues();

            for(int i = 0; i < this.area.Count; i++)
            {
                this.area.XValues[i] += 1;
            }

            this.trendFunction.Recalculate();

            Load                                         += Form_Load;
            this.refreshButton.Click                     += refreshButton_Click;
            this.trendStyleComboBox.SelectedIndexChanged += trendStyleComboBox_SelectedIndexChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.trendStyleComboBox.SelectedIndex = 0;
        }

        #endregion
        #region 갱신하기 버튼 클릭시 처리하기 - refreshButton_Click(sender, e)

        /// <summary>
        /// 갱신하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void refreshButton_Click(object sender, EventArgs e)
        {
            this.area.FillSampleValues();

            for(int i = 0; i < this.area.Count; i++)
            {
                this.area.XValues[i] += 1;
            }

            this.trendFunction.Recalculate();
        }

        #endregion
        #region 트렌드 스타일 선택 인덱스 변경시 처리하기 - trendStyleComboBox_SelectedIndexChanged(sender, e)

        /// <summary>
        /// 트렌드 스타일 선택 인덱스 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void trendStyleComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            switch(this.trendStyleComboBox.SelectedIndex)
            {
                case 0 :

                    this.trendFunction.Series.Title = "Trendline";
                    this.trendFunction.TrendStyle   = TrendStyles.Normal; 

                    break;

                case 1 :

                    this.trendFunction.Series.Title = "Exp.trendline";
                    this.trendFunction.TrendStyle   = TrendStyles.Exponential;

                    break;

                case 2 :

                    this.trendFunction.Series.Title = "Log.trendline";
                    this.trendFunction.TrendStyle   = TrendStyles.Logarithmic;

                    break;
            }
        }

        #endregion
    }
}